<?php

/**
 * Controller Class: Email admin for queries.
 * @author Jason Schoeman
 * @return string
 */
class EmailAdmin extends PHPDS_controller
{

	/**
	 * Execute Controller
	 * @author Jason Schoeman
	 */
	public function execute()
	{
		//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
		// Load Extra Classes ////////////////////////////////////////////////////////////////////////////////////////////////////
		$email = $this->factory('mailer');
		$wysiwyg = $this->factory('wysiwygEditor');
		$wysiwyg->wysiwygLoad();

		/* @var $crud crud */
		$crud = $this->factory('crud');

		$this->template->heading(_('Query Assistance'));

		$crud->addField('user_email', $this->configuration['user_email']);
		$crud->addField('name', $this->configuration['user_display_name']);
		$crud->addField('priority', 3);
		$crud->addField('query_type', 1);

		$settings_ = $this->db->getSettings(array('setting_support_email', 'setting_admin_email'), 'PHPDevShell');
		$admin_email = $settings_['setting_admin_email'];

		if (! empty($settings_['setting_support_email'])) {
			$options = explode(",", $settings_['setting_support_email']);
			$i = 0;
			foreach	($options as $option) {
				$row = explode(":", $option);
				$i++;
				if (! empty($row[0]) && ! empty($row[1])) {
					if ($row[0] == 'default')
						$email_[$i] = $admin_email;
					else
						$email_[$i] = $row[0];
					$type_[$i] = $row[1];
				}
			}
		}


		if ($crud->POST('send_mail')) {

			if (!$crud->isEmail('email_from'))
				$crud->error(_('Please provide a valid email address'));

			if (!$crud->is('query_type'))
				$crud->error(_('Please select type of query'));

			if (!$crud->is('name'))
				$crud->error(_('Please select type of query'));

			if (!$crud->is('subject'))
				$crud->error(_('Please provide a subject'));

			if (!$crud->is('message'))
				$crud->error(_('Please provide a query message'));

			$crud->is('priority');

			// If user tries to send another email in less then 60 seconds, reply with an error.
			if (!empty($_SESSION['hold'])) {
				$seconds_ = $this->configuration['time'] - $_SESSION['hold'];
				if ($seconds_ < 60)
					$crud->errorElse(sprintf(_('You can not send another message within 60 seconds, you have waited %s seconds.'), $seconds_));
			}

			if ($crud->ok()) {
				$message = $this->template->htmlEntityDecode($crud->f->message);

				foreach ($email_ as $key => $email__) {
					if ($admin_email != $email__)
						$email__ = $admin_email . "," . $email__;

					if ($key == $crud->f->query_type) {
						$email->FromName = $crud->f->name;
						if ($email->sendmail("$email__", $type_[$key] . ": " . $crud->f->subject, $message, "{$crud->f->email_from}", null, null, null, null, null, 'text/html', $crud->f->priority)) {
							$this->template->ok(sprintf(_('Thanks you %s, The query (%s) was sent successfully.'), "{$crud->f->email_from} \"{$crud->f->name}\"", $type_[$key]));
							$_SESSION['hold'] = $this->configuration['time'];
						}
					}
				}
			} else {
				$crud->errorShow();
			}
		}

		$view = $this->factory('views');

		$view->set('send_message', _('Send Message'));
		$view->set('self_url', $this->navigation->selfUrl());
		$view->set('email_from', $crud->f->email_from);
		$view->set('name', $crud->f->name);
		$view->set('id', $this->configuration['user_id']);
		$view->set('user_email', $crud->f->user_email);
		$view->set('subject', $crud->f->subject);
		$view->set('message', $crud->f->message);
		$view->set('query_type', $crud->radio('query_type', $type_, array($crud->f->query_type)));
		$view->set('priority', $crud->radio('priority', array(1=>_('High'), 3=>_('Normal'), 5=>_('Low')), array($crud->f->priority)));
		$view->set('post_validation', $this->security->postValidation());

		$view->show();
	}
}

return 'EmailAdmin';
